==> google-cloud-recommendations-ai-0.8.1.tar.gz: google-cloud-recommendations-ai-0.8.1/google/cloud/recommendationengine_v1beta1/services/prediction_api_key_registry/transports/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
from typing import Dict, Type

from .base import PredictionApiKeyRegistryTransport
from .grpc import PredictionApiKeyRegistryGrpcTransport
from .grpc_asyncio import PredictionApiKeyRegistryGrpcAsyncIOTransport
from .rest import PredictionApiKeyRegistryRestTransport
from .rest import PredictionApiKeyRegistryRestInterceptor


# Compile a registry of transports.
_transport_registry = (
    OrderedDict()
)  # type: Dict[str, Type[PredictionApiKeyRegistryTransport]]
_transport_registry["grpc"] = PredictionApiKeyRegistryGrpcTransport
_transport_registry["grpc_asyncio"] = PredictionApiKeyRegistryGrpcAsyncIOTransport
_transport_registry["rest"] = PredictionApiKeyRegistryRestTransport

__all__ = (
    "PredictionApiKeyRegistryTransport",
    "PredictionApiKeyRegistryGrpcTransport",
    "PredictionApiKeyRegistryGrpcAsyncIOTransport",
    "PredictionApiKeyRegistryRestTransport",
    "PredictionApiKeyRegistryRestInterceptor",
)

==> google-cloud-recommendations-ai-0.10.9.tar.gz: google-cloud-recommendations-ai-0.10.9/google/cloud/recommendationengine_v1beta1/services/prediction_api_key_registry/transports/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
from typing import Dict, Type

from .base import PredictionApiKeyRegistryTransport
from .grpc import PredictionApiKeyRegistryGrpcTransport
from .grpc_asyncio import PredictionApiKeyRegistryGrpcAsyncIOTransport
from .rest import (
    PredictionApiKeyRegistryRestInterceptor,
    PredictionApiKeyRegistryRestTransport,
)

# Compile a registry of transports.
_transport_registry = (
    OrderedDict()
)  # type: Dict[str, Type[PredictionApiKeyRegistryTransport]]
_transport_registry["grpc"] = PredictionApiKeyRegistryGrpcTransport
_transport_registry["grpc_asyncio"] = PredictionApiKeyRegistryGrpcAsyncIOTransport
_transport_registry["rest"] = PredictionApiKeyRegistryRestTransport

__all__ = (
    "PredictionApiKeyRegistryTransport",
    "PredictionApiKeyRegistryGrpcTransport",
    "PredictionApiKeyRegistryGrpcAsyncIOTransport",
    "PredictionApiKeyRegistryRestTransport",
    "PredictionApiKeyRegistryRestInterceptor",
)
